Struct scratchstack_aws_principal::details::AssumedRoleDetails [−][src]
pub struct AssumedRoleDetails<T: Data> { pub partition: String, pub account_id: String, pub role_name: String, pub session_name: String, pub data: T, }
Details about an assumed role.
Fields
partition: StringThe partition this principal exists in.
account_id: StringThe account id.
role_name: StringName of the role, case-insensitive.
session_name: StringSession name for the assumed role.
data: TPrincipal flavor-specific data.
Implementations
impl<T: Data> AssumedRoleDetails<T>[src]
impl<T: Data> AssumedRoleDetails<T>[src]pub fn new<S1, S2, S3, S4>(
partition: S1,
account_id: S2,
role_name: S3,
session_name: S4,
data: T
) -> Result<Self, PrincipalError> where
S1: Into<String>,
S2: Into<String>,
S3: Into<String>,
S4: Into<String>, [src]
partition: S1,
account_id: S2,
role_name: S3,
session_name: S4,
data: T
) -> Result<Self, PrincipalError> where
S1: Into<String>,
S2: Into<String>,
S3: Into<String>,
S4: Into<String>,
Create an AssumedRoleDetails object.
Arguments:
account_id: The 12 digit account id. This must be composed of 12 ASCII digits or a PrincipalError::InvalidAccountId error will be returned.role_name: The name of the role being assumed. This must meet the following requirements or a PrincipalError::InvalidRoleName error will be returned:- The name must contain between 1 and 64 characters.
- The name must be composed to ASCII alphanumeric characters or one of
, - . = @ _.
session_name: A name to assign to the session. This must meet the following requirements or a PrincipalError::InvalidSessionName error will be returned:- The session name must contain between 2 and 64 characters.
- The session name must be composed to ASCII alphanumeric characters or one of
, - . = @ _.
data: Principal flavor-specific data.
Return value
If all of the requirements are met, an AssumedRoleDetails object is returned. Otherwise, a PrincipalError error is returned.